# Training API Reference

## Trainer

::: lmt.training.trainer.Trainer

## Configuration

::: lmt.training.config.BaseTrainingConfig

## Curriculum Learning

::: lmt.training.curriculum.CurriculumSchedule

::: lmt.training.curriculum.SequenceLengthCurriculum
